@@ -1,4 +1,4 @@
-/* cio.c   by Michael Thorpe   2002-12-27 */
+/* cio.c   by Michael Thorpe   2004-05-14 */
 
 #include <errno.h>
 #include <signal.h>
@@ -22,6 +22,7 @@ struct generic_message {
    char *message;
 };
 
+/* These must be sorted in descending order of status number */
 static struct generic_message generic_messages[]={
    {555,"Requested action not taken: type or stru mismatch."}, /* RFC1123 */
    {554,"Requested action not taken: invalid REST parameter."}, /* RFC1123 */
@@ -81,20 +82,20 @@ tryagain:
             goto tryagain;
          if(errno != EAGAIN)
             return(1);
-      } else if(i==l) {
-         return(0);
       } else {
          s+=i;
          l-=i;
       }
    }
+   if(l==0)
+      return(0);
    tmp=(char *)realloc(c->coutbuf,l+c->coutbuflen);
    if(!tmp) {
       log(c,LOG_FAIL,"Couldn't allocate memory!\n");
       return(1);
    }
+   memcpy(tmp+c->coutbuflen,s,l);
    c->coutbuf=tmp;
-   memcpy(c->coutbuf+c->coutbuflen,s,l);
    c->coutbuflen+=l;
    return(0);
 }
@@ -106,13 +107,12 @@ int putline(conn *c,unsigned int status,char *message) {
    if(!message) {
       for(i=0;status<generic_messages[i].status;i++)
          ;
-      if(generic_messages[i].status==status)
-         message=generic_messages[i].message;
-      if(!message) {
+      if(generic_messages[i].status != status) {
          log(c,LOG_FAIL,"Unimplemented error code!");
          putline(c,421,0);
          return(-1);
       }
+      message=generic_messages[i].message;
    }
    while((s=strchr(message,'\n'))) {
       i=s-message;
