@@ -1,4 +1,4 @@
-/* cmd.c   by Michael Thorpe   2003-08-02 */
+/* cmd.c   by Michael Thorpe   2004-06-18 */
 
 #include <ctype.h>
 #include <stdlib.h>
@@ -102,10 +102,11 @@ int cmd_port(conn *c,char *arg) {
    sprintf(addr,"%u.%u.%u.%u",a[0],a[1],a[2],a[3]);
    if(strcmp(c->raddr,addr))
       return(putline(c,501,0));
-   if(c->fdd>=0)
+   if(-1 != c->fdd)
       dclose(c,0);
    c->drport=port;
-   c->dstate=DSTATE_ACTIVE;
+   c->dmode=DMODE_ACTIVE;
+   c->dstate=DSTATE_CLOSED;
    return(putline(c,200,0));
 }
 
@@ -210,24 +211,24 @@ static char *logquote(const char *line) {
       }
    }
    s[j]='\0';
-	return(s);
+   return(s);
 }
 
 int do_cmd(conn *c,char *line) {
    int i,j,k;
-	char *tmp;
+   char *tmp;
 
    for(i=0;strncasecmp(line,cmds[i].cmd,j=strlen(cmds[i].cmd));i++)
       ;
    if(j==4 && !strncasecmp(line,"PASS",4) && (line[4]==' ' || line[4]=='\t'))
       log(c,LOG_COMMAND,"PASS <hidden>");
    else {
-		tmp=logquote(line);
-		if(!tmp)
-			return(1);
+      tmp=logquote(line);
+      if(!tmp)
+         return(1);
       log(c,LOG_COMMAND,tmp);
-		free(tmp);
-	}
+      free(tmp);
+   }
    if(!j)
       return(putline(c,500,0));
    if(line[j] != ' ' && line[j] != '\0' && line[j] != '\t')
