@@ -1,4 +1,4 @@
-/* dir.c   by Michael Thorpe   2003-08-02 */
+/* dir.c   by Michael Thorpe   2004-06-18 */
 
 #include <errno.h>
 #include <fcntl.h>
@@ -171,8 +171,7 @@ static int dolist(conn *c,char *arg,int stat) {
       return(putline(c,450,0));
    if(!c->glob.gl_pathc)
       return(putline(c,250,0));
-   c->direction=DSTATE_OUT;
-   if(dopen(c)) {
+   if(dopen(c,DIRECTION_OUT)) {
       globfree(&c->glob);
       return(putline(c,425,0));
    }
@@ -235,8 +234,7 @@ static int dolist(conn *c,char *arg,int stat) {
    d=opendir(".");
    if(!d)
       return(putline(c,450,0));
-   c->direction=DSTATE_OUT;
-   if(dopen(c)) {
+   if(dopen(c,DIRECTION_OUT)) {
       closedir(d);
       return(putline(c,425,0));
    }
