@@ -1,4 +1,4 @@
-/* ftpd.h   by Michael Thorpe   2003-08-02 */
+/* ftpd.h   by Michael Thorpe   2004-06-18 */
 
 #include "conf.h"
 #include <sys/time.h>
@@ -46,13 +46,16 @@
 /* We want this connection closed and deleted now: */
 #define STATE_CLOSE   3
 
-#define DSTATE_NONE     0
-#define DSTATE_ACTIVE   1
-#define DSTATE_PASSIVE  2
-#define DSTATE_LISTEN   3
-#define DSTATE_IN       4
-#define DSTATE_CONNECT  5
-#define DSTATE_OUT      6
+#define DMODE_ACTIVE   0
+#define DMODE_PASSIVE  1
+
+#define DIRECTION_NONE  0
+#define DIRECTION_IN    1
+#define DIRECTION_OUT   2
+
+#define DSTATE_CLOSED   0
+#define DSTATE_OPENING  1
+#define DSTATE_OPEN     2
 
 #define INITIAL_TIMEOUT  60
 #define NORMAL_TIMEOUT  600
@@ -67,6 +70,7 @@ struct listener {
    struct listener *prev,*next;
    int fdc;
    char *addr;
+   char *external_addr;
    unsigned short cport;
 };
 
@@ -90,8 +94,9 @@ struct connection {
    size_t doutbuflen;
    char state;
    char cinstate;
-   char dstate;
+   char dmode;
    char direction;
+   char dstate;
    char dostat;
 #if ALLOW_GLOBBING
    glob_t glob;
@@ -105,7 +110,7 @@ struct connection {
    char type;
    char subtype;
    char structure;
-   char *laddr,*raddr;
+   char *laddr,*raddr,*external_laddr;
    unsigned short lport,rport;
    unsigned short dlport,drport;
    char *user;
@@ -130,7 +135,7 @@ int dwriterec(conn *c,char *buf,size_t len);
 #define davail(c,l) ((l)+(c)->doutbuflen<MAX_OUT_BUF)
 int dflush(conn *c);
 int dout(conn *c);
-int dopen(conn *c);
+int dopen(conn *c,int direction);
 int dclose(conn *c,int failure);
 int derror(conn *c);
 /* dir.c */
@@ -162,7 +167,7 @@ int parseport(const char *s,const char **post,unsigned short *port);
 int bindaddrport(const char *addr,unsigned short port);
 conn *newconn(int fd,struct sockaddr_in *sar,listener *l);
 void delconn(conn *c);
-int newlistener(const char *addr,unsigned short port);
+int newlistener(const char *addr,unsigned short port,const char *external_addr);
 int dellistener(const char *addr,unsigned short port);
 int laccept(listener *l);
 int lerror(listener *l);
