@@ -1,6 +1,7 @@
-/* select.c   by Michael Thorpe   2003-08-02 */
+/* select.c   by Michael Thorpe   2004-06-18 */
 
 #include <errno.h>
+#include <string.h>
 #include <unistd.h>
 #include <sys/time.h>
 #include <sys/types.h>
@@ -75,17 +76,25 @@ void doloop() {
          if(c->fdd != -1) {
             i=i>c->fdd?i:c->fdd;
             switch(c->dstate) {
-            case DSTATE_NONE:
-            case DSTATE_ACTIVE:
-            case DSTATE_PASSIVE:
+            case DSTATE_OPEN:
+               switch(c->direction) {
+               case DIRECTION_IN:
+                  FD_SET(c->fdd,&r);
+                  break;
+               case DIRECTION_OUT:
+                  FD_SET(c->fdd,&w);
+                  break;
+               }
                break;
-            case DSTATE_LISTEN:
-            case DSTATE_IN:
-               FD_SET(c->fdd,&r);
-               break;
-            case DSTATE_CONNECT:
-            case DSTATE_OUT:
-               FD_SET(c->fdd,&w);
+            case DSTATE_OPENING:
+               switch(c->dmode) {
+               case DMODE_ACTIVE:
+                  FD_SET(c->fdd,&w);
+                  break;
+               case DMODE_PASSIVE:
+                  FD_SET(c->fdd,&r);
+                  break;
+               }
                break;
             }
             FD_SET(c->fdd,&x);
@@ -164,32 +173,36 @@ void doloop() {
                continue;
             }
             switch(c->dstate) {
-            case DSTATE_NONE:
-            case DSTATE_ACTIVE:
-            case DSTATE_PASSIVE:
-               break;
-            case DSTATE_LISTEN:
-               if(FD_ISSET(c->fdd,&r))
-                  if(daccept(c))
-                     continue;
-               break;
-            case DSTATE_IN:
-               if(FD_ISSET(c->fdd,&r))
-                  if(c->callback(c))
-                     continue;
-               break;
-            case DSTATE_CONNECT:
-               if(FD_ISSET(c->fdd,&w))
-                  if(dconnect(c))
-                     continue;
-               break;
-            case DSTATE_OUT:
-               if(FD_ISSET(c->fdd,&w)) {
-                  if(dout(c))
-                     continue;
-                  if(c->callback)
+            case DSTATE_OPEN:
+               switch(c->direction) {
+               case DIRECTION_IN:
+                  if(FD_ISSET(c->fdd,&r))
                      if(c->callback(c))
                         continue;
+                  break;
+               case DIRECTION_OUT:
+                  if(FD_ISSET(c->fdd,&w)) {
+                     if(dout(c))
+                        continue;
+                     if(c->callback)
+                        if(c->callback(c))
+                           continue;
+                  }
+                  break;
+               }
+               break;
+            case DSTATE_OPENING:
+               switch(c->dmode) {
+               case DMODE_ACTIVE:
+                  if(FD_ISSET(c->fdd,&w))
+                     if(dconnect(c))
+                        continue;
+                  break;
+               case DMODE_PASSIVE:
+                  if(FD_ISSET(c->fdd,&r))
+                     if(daccept(c))
+                        continue;
+                  break;
                }
                break;
             }
